/**
 * Lyceenne Maker J, created by Claire "Milena" Billaud
 * 12 mai 09
 * Copyright (c) 2009, Claire "Milena" Billaud
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Claire Billaud, Milena, nor the
 *       names of other contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package controls;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JComboBox;
import javax.swing.JOptionPane;

import models.CharacterAbility;
import program.LyceenneMakerJ;
import views.AbilitiesPanel;

/**
 * Performs change in character when ability score is modified.
 * @author milena
 *
 */
public class AbilityActionListener implements ActionListener {

	private AbilitiesPanel abilitiesPanel;
	
	/**
	 * Constructor
	 * @param abilitiesPanel
	 */
	public AbilityActionListener(AbilitiesPanel abilitiesPanel) {
		super();
		this.abilitiesPanel = abilitiesPanel;
	}

	/* (non-Javadoc)
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed(ActionEvent e) {
		JComboBox cb = (JComboBox) e.getSource();
		int newScore = Integer.parseInt((String) cb.getSelectedItem());
		CharacterAbility selectedAbility = getMatchingAbility(cb);
		int previousScore = selectedAbility.getBonus();
		if(LyceenneMakerJ.getTotalGenerationPoints() + previousScore - newScore < 0)	{
			JOptionPane.showMessageDialog(abilitiesPanel, "Plus assez de points de génération !", "Impossible", JOptionPane.ERROR_MESSAGE);
			cb.setSelectedItem(Integer.toString(previousScore));
		}else	{
			selectedAbility.setBonus(newScore);
			LyceenneMakerJ.setTotalGenerationPoints(LyceenneMakerJ.getTotalGenerationPoints() + previousScore - newScore);
		}
		LyceenneMakerJ.getCurrentCharacter().recalcAllAbilities();
		abilitiesPanel.getAbilityTotals().get(selectedAbility.getName()).setText(Integer.toString(selectedAbility.getTotalScore()));
		abilitiesPanel.getTotalGenerationPoints().setText(Integer.toString(LyceenneMakerJ.getTotalGenerationPoints()));
	}
	
	/**
	 * Returns the character ability corresponding to the checkbox
	 * @param check the checkbox selected
	 * @return the character ability, or null
	 */
	private CharacterAbility getMatchingAbility(JComboBox cb)	{
		for(String abilityName : abilitiesPanel.getAbilityScores().keySet())	{
			if(cb == abilitiesPanel.getAbilityScores().get(abilityName))	{
				return LyceenneMakerJ.getCurrentCharacter().getAbilityByName(abilityName);
			}
		}
		return null;
	}

}
