/**
 * Lyceenne Maker J, created by Claire "Milena" Billaud
 * 12 mai 09
 * Copyright (c) 2009, Claire "Milena" Billaud
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Claire Billaud, Milena, nor the
 *       names of other contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package controls;

import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.JCheckBox;
import javax.swing.JOptionPane;

import models.CharacterAbility;
import program.LyceenneMakerJ;
import views.AbilitiesPanel;

/**
 * Item listener for main ability change.
 * @author milena
 *
 */
public class MainAbilityItemListener implements ItemListener {

	private AbilitiesPanel abilitiesPanel;
	
	/**
	 * Constructor
	 * @param abilitiesPanel
	 */
	public MainAbilityItemListener(AbilitiesPanel abilitiesPanel) {
		super();
		this.abilitiesPanel = abilitiesPanel;
	}

	/* (non-Javadoc)
	 * @see java.awt.event.ItemListener#itemStateChanged(java.awt.event.ItemEvent)
	 */
	public void itemStateChanged(ItemEvent e) {
		JCheckBox check = (JCheckBox) e.getItemSelectable();
		CharacterAbility selectedAbility = getMatchingAbility(check);
		if(check.isSelected())	{	//an ability becomes main
			if(LyceenneMakerJ.getTotalMainAbilities() == 0)	{	//not enough main abilities available
				JOptionPane.showMessageDialog(abilitiesPanel, "Impossible de choisir plus de talents", "Impossible", JOptionPane.ERROR_MESSAGE);
				LyceenneMakerJ.setTotalMainAbilities(LyceenneMakerJ.getTotalMainAbilities() - 1);
				//warning, this starts the listener once more and increments totalMainAbilities ...
				check.setSelected(false);
			}else	{
				selectedAbility.setMainAbility(true);
				if(selectedAbility.isUnusableByDefault())	{
					abilitiesPanel.getAbilityScores().get(selectedAbility.getName()).setEnabled(true);
				}
				LyceenneMakerJ.setTotalMainAbilities(LyceenneMakerJ.getTotalMainAbilities() - 1);
			}
		}else	{	//a main ability becomes normal
			selectedAbility.setMainAbility(false);
			if(selectedAbility.isUnusableByDefault())	{
				LyceenneMakerJ.setTotalGenerationPoints(LyceenneMakerJ.getTotalGenerationPoints() + selectedAbility.getBonus());
				selectedAbility.setBonus(0);
				abilitiesPanel.getAbilityScores().get(selectedAbility.getName()).setEnabled(false);
				abilitiesPanel.getAbilityScores().get(selectedAbility.getName()).setSelectedItem("0");
			}
			LyceenneMakerJ.setTotalMainAbilities(LyceenneMakerJ.getTotalMainAbilities() + 1);
		}
		LyceenneMakerJ.getCurrentCharacter().recalcAllAbilities();
		abilitiesPanel.getAbilityTotals().get(selectedAbility.getName()).setText(Integer.toString(selectedAbility.getTotalScore()));
		abilitiesPanel.getTotalMainAbilities().setText(Integer.toString(LyceenneMakerJ.getTotalMainAbilities()));
		abilitiesPanel.getTotalGenerationPoints().setText(Integer.toString(LyceenneMakerJ.getTotalGenerationPoints()));
	}
	
	/**
	 * Returns the character ability corresponding to the checkbox
	 * @param check the checkbox selected
	 * @return the character ability, or null
	 */
	private CharacterAbility getMatchingAbility(JCheckBox check)	{
		for(String abilityName : abilitiesPanel.getAbilityMains().keySet())	{
			if(check == abilitiesPanel.getAbilityMains().get(abilityName))	{
				return LyceenneMakerJ.getCurrentCharacter().getAbilityByName(abilityName);
			}
		}
		return null;
	}

}
