/**
 * Lyceenne Maker J, created by Claire "Milena" Billaud
 * 18 mai 09
 * Copyright (c) 2009, Claire "Milena" Billaud
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Claire Billaud, Milena, nor the
 *       names of other contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package controls;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JOptionPane;

import program.LyceenneMakerJ;
import utilities.StandardRules;
import views.FourthWindow;
import views.ThirdWindow;

/**
 * Checks subjects and goes to history screen.
 * @author milena
 *
 */
public class Next3ActionListener implements ActionListener {
	
	private ThirdWindow thirdWindow;

	/**
	 * Constructor
	 * @param thirdWindow the calling window
	 */
	public Next3ActionListener(ThirdWindow thirdWindow) {
		super();
		this.thirdWindow = thirdWindow;
	}

	/* (non-Javadoc)
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed(ActionEvent e) {
		JButton jb = (JButton) e.getSource();
		boolean alertsActive = false;
		boolean numberSubjectsError = false;
		for(JComboBox cb : thirdWindow.getSubjectsListPanel().getSubjects().keySet())	{
			if(!StandardRules.hasSomethingSelected(cb))	{
				numberSubjectsError = true;
			}
		}
		if(numberSubjectsError){
			JOptionPane.showMessageDialog(jb, "Le nombre de matières ne correspond pas aux matières réellement choisies !", "Erreur", JOptionPane.ERROR_MESSAGE);
			return;
		}
		if(LyceenneMakerJ.getTotalSubjectPoints() > 0)	{
			JOptionPane.showMessageDialog(jb, "Tous les points de matières scolaires n'ont pas été répartis !", "Attention", JOptionPane.WARNING_MESSAGE);
			alertsActive = true;
		}
		if(alertsActive){
			int confirm = JOptionPane.showConfirmDialog(jb, "Il reste des données incomplètes ou modifiables.\n Continuer ?", "Attention", JOptionPane.YES_NO_OPTION, JOptionPane.QUESTION_MESSAGE);
			if(confirm == JOptionPane.YES_OPTION){	//YES
				goToNextScreen();
			}else	{	//NO
				return;
			}
		}else	{
			goToNextScreen();
		}
	}
	
	/**
	 * Loads next screen
	 *
	 */
	private void goToNextScreen()	{
		FourthWindow fourthWindow = new FourthWindow();
		thirdWindow.setVisible(false);
	}

}
