/**
 * Lyceenne Maker J, created by Claire "Milena" Billaud
 * 11 mai 09
 * Copyright (c) 2009, Claire "Milena" Billaud
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Claire Billaud, Milena, nor the
 *       names of other contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package controls;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.List;

import javax.swing.JComboBox;
import javax.swing.JOptionPane;

import models.Profile;
import program.LyceenneMakerJ;
import utilities.CharacterRules;
import utilities.StandardRules;
import views.ProfilesPanel;

/**
 * Performs changes in character if profiles are changed in ProfilesPanel.
 * @author milena
 *
 */
public class ProfileActionListener implements ActionListener {

	private ProfilesPanel profPanel;
	
	/**
	 * 
	 */
	public ProfileActionListener(ProfilesPanel profPanel) {
		super();
		this.profPanel = profPanel;
	}

	/* (non-Javadoc)
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed(ActionEvent e) {
		JComboBox selectedCb = (JComboBox) e.getSource();
		//saves character's previous profiles
		List<Profile> previousProfiles = new ArrayList<Profile>();
		for(Profile profile : LyceenneMakerJ.getCurrentCharacter().getProfiles())	{
			previousProfiles.add(profile);
		}
		String previousProfileSelected = findPreviousProfileSelected(previousProfiles);
		//delete profiles list and add from combo boxes
		LyceenneMakerJ.getCurrentCharacter().resetAllProfiles();
		for(JComboBox cb : profPanel.getAllProfilesList())	{
			if(StandardRules.hasSomethingSelected(cb))	{
				LyceenneMakerJ.getCurrentCharacter().getProfiles().add(LyceenneMakerJ.getConfig().getProfileByName((String) cb.getSelectedItem()));
			}
		}
		if(!CharacterRules.checkAlignmentAndMaxProfiles(LyceenneMakerJ.getCurrentCharacter()))	{
			JOptionPane.showMessageDialog(profPanel, "Nombre de profils incorrect !", "Impossible", JOptionPane.ERROR_MESSAGE);
			LyceenneMakerJ.getCurrentCharacter().resetAllProfiles();
			for(Profile profile : previousProfiles)	{
				LyceenneMakerJ.getCurrentCharacter().getProfiles().add(profile);
			}
			selectedCb.setSelectedItem(previousProfileSelected);
		}
		if(!CharacterRules.hasNoDoubleProfiles(LyceenneMakerJ.getCurrentCharacter()))	{
			JOptionPane.showMessageDialog(profPanel, "Profil déjà présent !", "Impossible", JOptionPane.ERROR_MESSAGE);
			LyceenneMakerJ.getCurrentCharacter().resetAllProfiles();
			for(Profile profile : previousProfiles)	{
				LyceenneMakerJ.getCurrentCharacter().getProfiles().add(profile);
			}
			selectedCb.setSelectedItem(previousProfileSelected);
		}
		LyceenneMakerJ.getCurrentCharacter().recalcAllAbilities();
		
	}
	
	/**
	 * Finds which profile was preiously selected (to rollback if there is an error).
	 * @param previousProfiles the list of the previous profiles
	 * @return the name of the previous profile, or "" if nothing was selected
	 */
	private String findPreviousProfileSelected(List<Profile> previousProfiles)	{
		String previousProfileSelected = "";
		for(Profile profile : previousProfiles){
			boolean isFound = false;
			for(JComboBox cb : profPanel.getAllProfilesList())	{
				if(StandardRules.hasSomethingSelected(cb) && profile.getName().equals((String) cb.getSelectedItem()))	{
					isFound = true;
					break;
				}
			}
			if(!isFound)	{
				previousProfileSelected = profile.getName();
			}
		}
		
		return previousProfileSelected;
	}

}
