/**
 * Lyceenne Maker J, created by Claire "Milena" Billaud
 * 17 mai 09
 * Copyright (c) 2009, Claire "Milena" Billaud
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Claire Billaud, Milena, nor the
 *       names of other contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package controls;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JComboBox;
import javax.swing.JOptionPane;

import models.CharacterSubject;
import program.LyceenneMakerJ;
import utilities.StandardRules;
import views.SubjectsListPanel;

/**
 * Modifies subject score when modified.
 * @author milena
 *
 */
public class SubjectBonusActionListener implements ActionListener {
	
	private SubjectsListPanel slistPanel;

	/**
	 * Constructor
	 * @param slistPanel the associated subjects list panel
	 */
	public SubjectBonusActionListener(SubjectsListPanel slistPanel) {
		super();
		this.slistPanel = slistPanel;
	}

	/* (non-Javadoc)
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed(ActionEvent e) {
		JComboBox selectedCb = (JComboBox) e.getSource();
		int newScore = Integer.parseInt((String) selectedCb.getSelectedItem());
		JComboBox nameCb = findAssociatedSubjectName(selectedCb);
		if(!StandardRules.hasSomethingSelected(nameCb))	{
//			JOptionPane.showMessageDialog(slistPanel, "Matière non sélectionnée !", "Impossible", JOptionPane.ERROR_MESSAGE);
			selectedCb.setSelectedItem("0");
		}else	{
			CharacterSubject subject = LyceenneMakerJ.getCurrentCharacter().getSubjectByName((String) nameCb.getSelectedItem());
			int previousScore = subject.getBonus();
			if(LyceenneMakerJ.getTotalSubjectPoints() + previousScore - newScore < 0)	{
				JOptionPane.showMessageDialog(slistPanel, "Plus assez de points de matières scolaires !", "Impossible", JOptionPane.ERROR_MESSAGE);
				selectedCb.setSelectedItem(Integer.toString(previousScore));
			}else	{
				subject.setBonus(newScore);
				LyceenneMakerJ.setTotalSubjectPoints(LyceenneMakerJ.getTotalSubjectPoints() + previousScore - newScore);
			}
		}
		LyceenneMakerJ.getCurrentCharacter().recalcAllSubjects();
		for(JComboBox cb : slistPanel.getSubjectTotals().keySet())	{
			if(StandardRules.hasSomethingSelected(cb))	{
				CharacterSubject modifiedSubject = LyceenneMakerJ.getCurrentCharacter().getSubjectByName((String) cb.getSelectedItem());
				slistPanel.getSubjectTotals().get(cb).setText(Integer.toString(modifiedSubject.getTotalScore()));
			}
		}
		slistPanel.getTotalSubjectsPoints().setText(Integer.toString(LyceenneMakerJ.getTotalSubjectPoints()));
	}
	
	/**
	 * Gets subject name combo box
	 * @param cb the bonus combo box
	 * @return the subject name combo box, or null if not found
	 */
	private JComboBox findAssociatedSubjectName(JComboBox cb){
		JComboBox resultCb = null;
		for(JComboBox nameCb : slistPanel.getSubjects().keySet())	{
			if(cb.equals(slistPanel.getSubjects().get(nameCb)))	{
				resultCb = nameCb;
				break;
			}
		}
		return resultCb;
	}

}
