/**
 * Lyceenne Maker J, created by Claire "Milena" Billaud
 * 17 mai 09
 * Copyright (c) 2009, Claire "Milena" Billaud
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Claire Billaud, Milena, nor the
 *       names of other contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package controls;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.List;

import javax.swing.JComboBox;
import javax.swing.JOptionPane;

import models.CharacterSubject;
import program.LyceenneMakerJ;
import utilities.CharacterRules;
import utilities.StandardRules;
import views.SubjectsListPanel;

/**
 * Changes character subjects when a subject name is changed.
 * @author milena
 *
 */
public class SubjectNameActionListener implements ActionListener {
	
	private SubjectsListPanel slistPanel;

	
	/**
	 * Constructor
	 * @param slistPanel the corresponding subjects list panel
	 */
	public SubjectNameActionListener(SubjectsListPanel slistPanel) {
		super();
		this.slistPanel = slistPanel;
	}

	/* (non-Javadoc)
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed(ActionEvent e) {
		JComboBox selectedCb = (JComboBox) e.getSource();
		//save character's previous subjects
		List<CharacterSubject> previousSubjects = new ArrayList<CharacterSubject>();
		for(CharacterSubject subject : LyceenneMakerJ.getCurrentCharacter().getSubjects())	{
			previousSubjects.add(subject);
		}
		String previousSubjectSelected = findPreviousSubjectSelected(previousSubjects);
		//delete subjects list and add from combo boxes
		LyceenneMakerJ.getCurrentCharacter().resetAllSubjects();
		for(JComboBox cb : slistPanel.getSubjects().keySet())	{
			if(StandardRules.hasSomethingSelected(cb))	{
				CharacterSubject subject = LyceenneMakerJ.getCurrentCharacter().addSubjectFromConfig(LyceenneMakerJ.getConfig(), (String) cb.getSelectedItem());
				subject.setBonus(Integer.parseInt((String) slistPanel.getSubjects().get(cb).getSelectedItem()));
			}
		}
		if(!CharacterRules.hasNoDoubleSubjects(LyceenneMakerJ.getCurrentCharacter()))	{
			JOptionPane.showMessageDialog(slistPanel, "Matière déjà présente !", "Impossible", JOptionPane.ERROR_MESSAGE);
			LyceenneMakerJ.getCurrentCharacter().resetAllSubjects();
			for(CharacterSubject subject : previousSubjects)	{
				LyceenneMakerJ.getCurrentCharacter().getSubjects().add(subject);
			}
			selectedCb.setSelectedItem(previousSubjectSelected);
		}
		//if there is no more subject selected here
		if(!StandardRules.hasSomethingSelected(selectedCb))	{
			int recoveredScore = Integer.parseInt((String) slistPanel.getSubjects().get(selectedCb).getSelectedItem());
			LyceenneMakerJ.setTotalSubjectPoints(LyceenneMakerJ.getTotalSubjectPoints() + recoveredScore);
			slistPanel.getSubjects().get(selectedCb).setSelectedItem("0");
			slistPanel.getSubjects().get(selectedCb).setEnabled(true);
			slistPanel.getSubjectTotals().get(selectedCb).setText(Integer.toString(LyceenneMakerJ.getCurrentCharacter().getCharacteristics().get("INT")));
		}else	{
			//if this subject has an associated ability
			if(LyceenneMakerJ.getConfig().getSubjectByName((String) selectedCb.getSelectedItem()).getAssociatedAbility() != null)	{
				int recoveredScore = Integer.parseInt((String) slistPanel.getSubjects().get(selectedCb).getSelectedItem());
				LyceenneMakerJ.setTotalSubjectPoints(LyceenneMakerJ.getTotalSubjectPoints() + recoveredScore);
				slistPanel.getSubjects().get(selectedCb).setSelectedItem("0");
				slistPanel.getSubjects().get(selectedCb).setEnabled(false);
			}else	{
				slistPanel.getSubjects().get(selectedCb).setEnabled(true);
			}
		}
		LyceenneMakerJ.getCurrentCharacter().recalcAllSubjects();
		for(JComboBox cb : slistPanel.getSubjectTotals().keySet())	{
			if(StandardRules.hasSomethingSelected(cb))	{
				CharacterSubject subject = LyceenneMakerJ.getCurrentCharacter().getSubjectByName((String) cb.getSelectedItem());
				slistPanel.getSubjectTotals().get(cb).setText(Integer.toString(subject.getTotalScore()));
			}
		}
		slistPanel.getTotalSubjectsPoints().setText(Integer.toString(LyceenneMakerJ.getTotalSubjectPoints()));
	}
	
	/**
	 * Finds which profile was preiously selected (to rollback if there is an error).
	 * @param previousProfiles the list of the previous profiles
	 * @return the name of the previous profile, or "" if nothing was selected
	 */
	private String findPreviousSubjectSelected(List<CharacterSubject> previousSubjects)	{
		String previousSubjectSelected = "";
		for(CharacterSubject subject : previousSubjects){
			boolean isFound = false;
			for(JComboBox cb : slistPanel.getSubjects().keySet())	{
				if(StandardRules.hasSomethingSelected(cb) && subject.getName().equals((String) cb.getSelectedItem()))	{
					isFound = true;
					break;
				}
			}
			if(!isFound)	{
				previousSubjectSelected = subject.getName();
			}
		}
		
		return previousSubjectSelected;
	}

}
