/**
 * Lyceenne Maker J, created by Claire "Milena" Billaud
 * 18 mai 09
 * Copyright (c) 2009, Claire "Milena" Billaud
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Claire Billaud, Milena, nor the
 *       names of other contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package utilities;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import models.CharacterAbility;
import models.CharacterSubject;
import models.Profile;
import program.LyceenneMakerJ;

/**
 * Creates lines to make a character sheet.
 * @author milena
 *
 */
public class CharacterSheetMaker {
	
	private List<String> lines;
	private File outputFile;

	/**
	 * Constructor
	 * @param character the character to export
	 * @param outputFile the file to which to export
	 */
	public CharacterSheetMaker(File outputFile) {
		this.lines = new ArrayList<String>();
		this.outputFile = outputFile;
	}
	
	/**
	 * Creates lines and adds to selected file.
	 *
	 */
	public void process()	{
		makeHeader();
		lines.add("\t<body>");
		makeOverviewAndProfiles();
		makeCharacteristics();
		makeAbilities();
		lines.add("\t\t<br />\n");
		makeSubjects();
		if(LyceenneMakerJ.getCurrentCharacter().getHistory() != null)	{
			makeHistory();
		}
		lines.add("\t</body>");
		lines.add("</html>");
		try	{
			FileUtils.writeLinesToFile(lines, outputFile.getAbsolutePath());
		}catch(Exception e)	{
			e.printStackTrace();
			return;
		}
	}
	
	/**
	 * Makes header, independant from character.
	 *
	 */
	private void makeHeader()	{
		lines.add("<html>\n");
		lines.add("\t<head>\n");
		lines.add("\t\t<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />\n");
		lines.add("\t\t<title>Fiche de personnage Lycéenne RPG 4.0</title>\n");
		lines.add("\t\t<style type=\"text/css\">\n");
		lines.add("\t\t\tbody{background-color:#FFCCFF;font-style:serif;}\n");
		lines.add("\t\t\th1{text-align:center;font-size:18px;font-weight:bold;}\n");
		lines.add("\t\t\ttable{border:1px solid black;}\n");
		lines.add("\t\t\tth{text-align:center;border:1px solid black;}\n");
		lines.add("\t\t\ttd{border:1px solid black;}\n");
		lines.add("\t\t</style>");
		lines.add("\t</head>");
	}
	
	/**
	 * Writes character overview and profiles
	 *
	 */
	private void makeOverviewAndProfiles()	{
		lines.add("\t\t<h1>" + LyceenneMakerJ.getCurrentCharacter().getName() + "</h1>\n");
		lines.add("\t\t<ul>\n");
		lines.add("\t\t\t<li><strong>Âge : </strong>" + Integer.toString(LyceenneMakerJ.getCurrentCharacter().getAge()) + " ans</li>\n");
		lines.add("\t\t\t<li><strong>Alignement : </strong>" + LyceenneMakerJ.getCurrentCharacter().getAlignment().getName() + "</li>\n");
		lines.add("\t\t\t<li><strong>Réputation : </strong>" + LyceenneMakerJ.getCurrentCharacter().getReputationLevel() + " - " +
				LyceenneMakerJ.getCurrentCharacter().getReputation() + "</li>\n");
		lines.add("\t\t</ul>\n");
		lines.add("\t\t<ul>\n");
		lines.add("\t\t\t<li><strong>Profils positifs</strong></li>\n");
		lines.add("\t\t\t<ul>\n");
		for(Profile profile : LyceenneMakerJ.getCurrentCharacter().getProfiles())	{
			if("Positif".equals(profile.getType()))	{
				lines.add("\t\t\t\t<li>" + profile.getName() + "</li>\n");
			}
		}
		lines.add("\t\t\t</ul>\n");
		lines.add("\t\t\t<li><strong>Profils négatifs</strong></li>\n");
		lines.add("\t\t\t<ul>\n");
		for(Profile profile : LyceenneMakerJ.getCurrentCharacter().getProfiles())	{
			if("Négatif".equals(profile.getType()))	{
				lines.add("\t\t\t\t<li>" + profile.getName() + "</li>\n");
			}
		}
		lines.add("\t\t\t</ul>\n");
		lines.add("\t\t\t<li><strong>Profils neutres avantageux</strong></li>\n");
		lines.add("\t\t\t<ul>\n");
		for(Profile profile : LyceenneMakerJ.getCurrentCharacter().getProfiles())	{
			if("Neutre avantageux".equals(profile.getType()))	{
				lines.add("\t\t\t\t<li>" + profile.getName() + "</li>\n");
			}
		}
		lines.add("\t\t\t</ul>\n");
		lines.add("\t\t\t<li><strong>Profils neutres désavantageux</strong></li>\n");
		lines.add("\t\t\t<ul>\n");
		for(Profile profile : LyceenneMakerJ.getCurrentCharacter().getProfiles())	{
			if("Neutre désavantageux".equals(profile.getType()))	{
				lines.add("\t\t\t\t<li>" + profile.getName() + "</li>\n");
			}
		}
		lines.add("\t\t\t</ul>\n");
		lines.add("\t\t</ul>\n");
	}
	
	/**
	 * Writes characteristics and health points
	 *
	 */
	private void makeCharacteristics()	{
		lines.add("\t\t<table>\n");
		lines.add("\t\t\t<tr><th colspan=\"4\">Caracteristiques</td></tr>\n");
		lines.add("\t\t\t<tr><td>PHYsique</td><td>" + Integer.toString(LyceenneMakerJ.getCurrentCharacter().getCharacteristics().get("PHY")) +
				"</td><td>DEXtérité</td><td>"+ Integer.toString(LyceenneMakerJ.getCurrentCharacter().getCharacteristics().get("DEX")) + 
				"</td></tr>\n");
		lines.add("\t\t\t<tr><td>INTelligence</td><td>" + Integer.toString(LyceenneMakerJ.getCurrentCharacter().getCharacteristics().get("INT")) +
				"</td><td>PERception</td><td>" + Integer.toString(LyceenneMakerJ.getCurrentCharacter().getCharacteristics().get("PER")) +
				"</td></tr>\n");
		lines.add("\t\t\t<tr><td>CHArisme</td><td>" + Integer.toString(LyceenneMakerJ.getCurrentCharacter().getCharacteristics().get("CHA")) +
				"</td><td>SENsibilité</td><td>" + Integer.toString(LyceenneMakerJ.getCurrentCharacter().getCharacteristics().get("SEN")) +
				"</td></tr>\n");
		lines.add("\t\t</table>\n");
		lines.add("\t\t<ul>\n");
		lines.add("\t\t\t<li><strong>Points de sante : </strong>" + Integer.toString(LyceenneMakerJ.getCurrentCharacter().getCharacteristics().get("PHY") * 3) + "</li>\n");
		lines.add("\t\t</ul>\n");
	}
	
	/**
	 * Writes abilities
	 *
	 */
	private void makeAbilities()	{
		lines.add("\t\t<table>");
		lines.add("\t\t\t<tr><th colspan=\"6\">Talents</th></tr>\n");
		lines.add("\t\t\t<tr><th>Nom</th><th>Caractéristique</th><th>Bonus</th><th>Modificateur</th><th>Score total</th><th>Principal ?</th></tr>\n");
		for(CharacterAbility ability : LyceenneMakerJ.getCurrentCharacter().getAbilities())	{
			String isMain = ability.isMainAbility() ? "X" : " ";
			String defaultModifier = ability.isUnusableByDefault() ? "X" : Integer.toString(ability.getDefaultModifier());
			String blurDefaultModifier = ability.isMainAbility() ? " style=\"color:#999999;\"" : "";
			lines.add("\t\t\t<tr><td>" + ability.getName() + "</td><td>" + ability.getCharacteristic() + "</td><td>" +
					Integer.toString(ability.getBonus()) + "</td><td" + blurDefaultModifier + ">" +
					defaultModifier + "</td><td>" +
					Integer.toString(ability.getTotalScore()) + "</td><td>" + isMain + "</td></tr>\n");
		}
		lines.add("\t\t</table>\n");
	}
	
	/**
	 * Writes subjects
	 *
	 */
	private void makeSubjects()	{
		lines.add("\t\t<table>\n");
		lines.add("\t\t\t<tr><th colspan=\"2\">Matières scolaires</th></tr>\n");
		lines.add("\t\t\t<tr><th>Nom</th><th>Score</th></tr>\n");
		for(CharacterSubject subject : LyceenneMakerJ.getCurrentCharacter().getSubjects())	{
			lines.add("\t\t\t<td>" + subject.getName() + "</td><td>" + Integer.toString(subject.getTotalScore()) + "</td></tr>\n");
		}
		lines.add("\t\t</table>\n");
	}
	
	/**
	 * Writes history
	 *
	 */
	private void makeHistory()	{
		lines.add("\t\t<ul>\n");
		lines.add("\t\t\t<li>Historique</li>\n");
		String history = LyceenneMakerJ.getCurrentCharacter().getHistory().replaceAll("\r\n", "<br />");
		history = history.replaceAll("\n", "<br />");
		lines.add("\t\t</ul>\n");
		lines.add("\t\t<p>" + history + "</p>\n");
	}

}
