/**
 * Lyceenne Maker J, created by Claire "Milena" Billaud
 * 25 avr. 09
 * Copyright (c) 2009, Claire "Milena" Billaud
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Claire Billaud, Milena, nor the
 *       names of other contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package utilities;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * Utilities class for file manipulation.
 * @author milena
 *
 */
public class FileUtils {
	
	private static String libFilesPath = "/lib/";
	
	/**
	 * Reads lines from a file
	 * @param filename the file to read
	 * @return the file content as a list of strings
	 * @throws FileNotFoundException
	 * @throws IOException
	 */
	public static List<String> readLinesFromFile(String filename) throws FileNotFoundException,IOException	{
		FileReader fre = null;
		BufferedReader bre = null;
		List<String> profilesList = new ArrayList<String>();
		String line = null;
		try	{
			fre = new FileReader(System.getProperty("user.dir") + libFilesPath + filename);
			bre = new BufferedReader(fre);
			while((line = bre.readLine()) != null)	{
				profilesList.add(line);
			}
			bre.close();
			fre.close();
			return profilesList;

		}catch(FileNotFoundException e)	{
			throw e;
		}catch(IOException e){
			throw e;
		}
	}
	
	/**
	 * Writes lines to an existing file.
	 * @param lines the set of lines to write
	 * @param filename the file name
	 * @throws FileNotFoundException
	 * @throws IOException
	 */
	public static void writeLinesToFile(List<String> lines, String filename) throws FileNotFoundException, IOException	{
		FileWriter fwr = null;
		BufferedWriter bwr = null;
		try	{
			fwr = new FileWriter(filename);
			bwr = new BufferedWriter(fwr);
			for(String line : lines)	{
				bwr.write(line);
			}
			bwr.close();
			fwr.close();
		}catch(FileNotFoundException e){
			throw e;
		}catch(IOException e){
			throw e;
		}
	}
	
	/**
	 * Similar to previous, but appends lines rather than replacing. Used to complete config files in edit mode.
	 * @param lines the set of lines to append
	 * @param filename the file name
	 * @throws FileNotFoundException
	 * @throws IOException
	 */
	public static void appendLinesToFile(List<String> lines, String filename) throws FileNotFoundException, IOException	{
		FileWriter fwr = null;
		BufferedWriter bwr = null;
		try	{
			fwr = new FileWriter(System.getProperty("user.dir") + libFilesPath + filename, true);
			bwr = new BufferedWriter(fwr);
			for(String line : lines)	{
				bwr.write(line);
			}
			bwr.close();
			fwr.close();
		}catch(FileNotFoundException e){
			throw e;
		}catch(IOException e){
			throw e;
		}
	}
	
	 /**
	  * Gets the extension of a file
	  * @param f the file to check
	  * @return its extension
	  */
    public static String getExtension(File f) {
        String ext = null;
        String s = f.getName();
        int i = s.lastIndexOf('.');

        if (i > 0 &&  i < s.length() - 1) {
            ext = s.substring(i+1).toLowerCase();
        }
        return ext;
    }



}
