/**
 * Lyceenne Maker J, created by Claire "Milena" Billaud
 * 12 mai 09
 * Copyright (c) 2009, Claire "Milena" Billaud
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Claire Billaud, Milena, nor the
 *       names of other contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package views;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.GridLayout;
import java.util.HashMap;
import java.util.Map;

import javax.swing.BorderFactory;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;

import models.CharacterAbility;
import program.LyceenneMakerJ;
import controls.AbilityActionListener;
import controls.MainAbilityItemListener;

/**
 * Abilities panel.
 * @author milena
 *
 */
public class AbilitiesPanel extends JPanel {

	private Map<String, JComboBox> abilityScores;
	private Map<String, JCheckBox> abilityMains;
	private Map<String, JLabel> abilityTotals;
	private JLabel totalGenerationPoints;
	private JLabel totalMainAbilities;
	private JPanel listPanel;
	private JPanel nameListPanel;
	private JPanel scoreListPanel;
	
	/**
	 * Constructor
	 */
	public AbilitiesPanel() {
		super();
		this.setLayout(new BorderLayout());
		this.setBorder(BorderFactory.createTitledBorder("Talents"));
		abilityScores = new HashMap<String, JComboBox>();
		abilityMains = new HashMap<String, JCheckBox>();
		abilityTotals = new HashMap<String, JLabel>();
		MainAbilityItemListener mainAbilityListener = new MainAbilityItemListener(this);
		AbilityActionListener abilityListener = new AbilityActionListener(this);
		listPanel = new JPanel();
		nameListPanel = new JPanel();
		scoreListPanel = new JPanel();
		listPanel.setLayout(new BorderLayout());
		nameListPanel.setLayout(new GridLayout(LyceenneMakerJ.getCurrentCharacter().getAbilities().size() + 1, 1, 5, 5));
		scoreListPanel.setLayout(new GridLayout(LyceenneMakerJ.getCurrentCharacter().getAbilities().size() + 1, 5, 5, 5));
		nameListPanel.add(new JLabel("Nom"));
		scoreListPanel.add(new JLabel("Caractéristique"));
		scoreListPanel.add(new JLabel("Score carac"));
		scoreListPanel.add(new JLabel("Bonus"));
		scoreListPanel.add(new JLabel("Principal ?"));
		scoreListPanel.add(new JLabel("Total"));
		
		initComboAndCheckBoxes(mainAbilityListener, abilityListener);
		
		printComboAndCheckBoxes();
		
		listPanel.add(nameListPanel, BorderLayout.WEST);
		listPanel.add(scoreListPanel, BorderLayout.CENTER);
		JScrollPane scrollPane = new JScrollPane(listPanel);
		this.add(scrollPane, BorderLayout.CENTER);
		
		totalGenerationPoints = new JLabel(Integer.toString(LyceenneMakerJ.getTotalGenerationPoints()));
		totalMainAbilities = new JLabel(Integer.toString(LyceenneMakerJ.getTotalMainAbilities()));
		
		JPanel scorePanel = new JPanel();
		scorePanel.setLayout(new FlowLayout());
		scorePanel.add(new JLabel("Points de génération :"));
		scorePanel.add(totalGenerationPoints);
		scorePanel.add(new JLabel("Talents à choisir :"));
		scorePanel.add(totalMainAbilities);
		this.add(scorePanel, BorderLayout.SOUTH);
	}
	
	private void initComboAndCheckBoxes(MainAbilityItemListener mainAbilityListener, AbilityActionListener abilityListener)	{
		for(CharacterAbility ability : LyceenneMakerJ.getCurrentCharacter().getAbilities())	{
			JComboBox cb = new JComboBox();
			JCheckBox check = new JCheckBox();
			JLabel label = new JLabel();
			//fill combo box
			for (int i = 0; i <= 10; i++) {
				cb.addItem(Integer.toString(i));
			}
			cb.setSelectedItem("0");
			cb.setEditable(false);
			if(ability.isUnusableByDefault())	{
				cb.setEnabled(false);
			}
			cb.addActionListener(abilityListener);
			// fill check box
			check.setSelected(false);
			check.addItemListener(mainAbilityListener);
			//fill label
			label.setText(Integer.toString(ability.getTotalScore()));
			//create maps
			abilityScores.put(ability.getName(), cb);
			abilityMains.put(ability.getName(), check);
			abilityTotals.put(ability.getName(), label);
		}
	}
	
	private void printComboAndCheckBoxes()	{
		for(CharacterAbility ability : LyceenneMakerJ.getCurrentCharacter().getAbilities())	{
			String printedName = ability.getName();
			if(ability.isUnusableByDefault())	{
				printedName += " (X)";
			}
			nameListPanel.add(new JLabel(printedName));
			scoreListPanel.add(new JLabel(ability.getCharacteristic()));
			scoreListPanel.add(new JLabel(Integer.toString(LyceenneMakerJ.getCurrentCharacter().getCharacteristics().get(ability.getCharacteristic()))));
			scoreListPanel.add(abilityScores.get(ability.getName()));
			scoreListPanel.add(abilityMains.get(ability.getName()));
			scoreListPanel.add(abilityTotals.get(ability.getName()));
		}
	}

	public Map<String, JCheckBox> getAbilityMains() {
		return abilityMains;
	}

	public Map<String, JComboBox> getAbilityScores() {
		return abilityScores;
	}

	public Map<String, JLabel> getAbilityTotals() {
		return abilityTotals;
	}

	public JLabel getTotalGenerationPoints() {
		return totalGenerationPoints;
	}

	public JLabel getTotalMainAbilities() {
		return totalMainAbilities;
	}

	
}
