/**
 * Lyceenne Maker J, created by Claire "Milena" Billaud
 * 22 sept. 09
 * Copyright (c) 2009, Claire "Milena" Billaud
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Claire Billaud, Milena, nor the
 *       names of other contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package views;

import java.awt.FlowLayout;
import java.awt.GridLayout;
import java.util.ArrayList;
import java.util.List;

import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JPanel;

import controls.ClearListActionListener;
import controls.SaveToFileActionListener;
import controls.ViewListActionListener;

/**
 * Base, generic edit panel conatining list and file for saving purpose.
 * @author milena
 *
 */
public class BaseEditPanel extends JPanel {

	protected List<String> editsList;
	protected JButton saveToListButton;
	protected JButton viewListButton;
	protected JButton clearListButton;
	protected JButton saveListToFileButton;
	protected String saveFileName;
	protected JPanel editingPanel;
	
	/**
	 * Constructor.
	 * @param title the title to display above the panel
	 * @param saveFileName the file where this panel must save
	 */
	public BaseEditPanel(String title, String saveFileName)	{
		super();
		editsList = new ArrayList<String>();
		this.saveFileName = saveFileName;
		this.setBorder(BorderFactory.createTitledBorder(title));
		this.setLayout(new GridLayout(2,1));
		editingPanel = new JPanel();
		this.add(editingPanel);
		JPanel buttonsPanel = new JPanel();
		buttonsPanel.setLayout(new FlowLayout());
		saveToListButton = new JButton("Ajouter aux éditions en cours");
		viewListButton = new JButton("Voir les éditions en cours");
		clearListButton = new JButton("Annuler toutes les éditions en cours");
		saveListToFileButton = new JButton("Sauvegarder les éditions en cours");
		viewListButton.addActionListener(new ViewListActionListener(this));
		saveListToFileButton.addActionListener(new SaveToFileActionListener(this));
		clearListButton.addActionListener(new ClearListActionListener(this));
		buttonsPanel.add(saveToListButton);
		buttonsPanel.add(viewListButton);
		buttonsPanel.add(clearListButton);
		buttonsPanel.add(saveListToFileButton);
		this.add(buttonsPanel);
	}

	public List<String> getEditsList() {
		return editsList;
	}

	public String getSaveFileName() {
		return saveFileName;
	}

}
