/**
 * Lyceenne Maker J, created by Claire "Milena" Billaud
 * 7 mai 09
 * Copyright (c) 2009, Claire "Milena" Billaud
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Claire Billaud, Milena, nor the
 *       names of other contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package views;

import java.awt.FlowLayout;
import java.awt.GridLayout;

import javax.swing.BorderFactory;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import models.Alignment;
import program.LyceenneMakerJ;
import controls.AgeActionListener;
import controls.AlignmentActionListener;
import controls.NameKeyListener;
import controls.ReputationKeyListener;
import controls.ReputationLevelActionListener;

/**
 * Overview panel (name, age, alignment).
 * @author milena
 *
 */
public class OverviewPanel extends JPanel {

	private JTextField name;
	private JComboBox age;
	private JComboBox alignment;
	private JComboBox reputationLevel;
	
	/**
	 * Constructor
	 * @param config the current config, used for alignments combo list
	 */
	public OverviewPanel() {
		super();
		this.setLayout(new GridLayout(2, 1));
		this.setBorder(BorderFactory.createTitledBorder("Infos générales"));
		
		JPanel firstPanel = new JPanel();
		firstPanel.setLayout(new FlowLayout());
		
		name = new JTextField(20);
		name.addKeyListener(new NameKeyListener());
		
		age = new JComboBox();
		initAges();
		age.setEditable(false);
		age.addActionListener(new AgeActionListener());
		
		alignment = new JComboBox();
		initAlignmentsFromConfig();
		alignment.setEditable(false);
		alignment.addActionListener(new AlignmentActionListener());
		
		firstPanel.add(new JLabel("Nom : "));
		firstPanel.add(name);
		firstPanel.add(new JLabel("Âge : "));
		firstPanel.add(age);
		firstPanel.add(new JLabel("Alignement : "));
		firstPanel.add(alignment);
		this.add(firstPanel);
		
		JPanel secondPanel = new JPanel();
		secondPanel.setLayout(new FlowLayout());
		
		reputationLevel = new JComboBox();
		initReputationLevelsFromConfig();
		reputationLevel.setEditable(false);
		reputationLevel.addActionListener(new ReputationLevelActionListener());
		
		JTextField reputation = new JTextField(20);
		reputation.addKeyListener(new ReputationKeyListener());
		
		secondPanel.add(new JLabel("Réputation :"));
		secondPanel.add(reputationLevel);
		secondPanel.add(reputation);
		this.add(secondPanel);
	}
	
	/**
	 * Loads alignments combo box from config.
	 *
	 */
	private void initAlignmentsFromConfig()	{
		for(Alignment alignmentToAdd : LyceenneMakerJ.getConfig().getAlignments())	{
			alignment.addItem(alignmentToAdd.getName());
		}
	}
	
	/**
	 * Loads ages combo box.
	 *
	 */
	private void initAges()	{
		age.addItem("15");
		age.addItem("16");
		age.addItem("17");
		age.addItem("18");
		age.addItem("19");
	}
	
	/**
	 * Loads reputation levels combo box from config.
	 *
	 */
	private void initReputationLevelsFromConfig()	{
		for(String level : LyceenneMakerJ.getConfig().getReputationLevels())	{
			reputationLevel.addItem(level);
		}
	}

}
