/**
 * Lyceenne Maker J, created by Claire "Milena" Billaud
 * 11 mai 09
 * Copyright (c) 2009, Claire "Milena" Billaud
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Claire Billaud, Milena, nor the
 *       names of other contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package views;

import java.awt.BorderLayout;
import java.awt.GridLayout;
import java.util.ArrayList;
import java.util.List;

import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JPanel;

import models.Profile;
import program.LyceenneMakerJ;
import controls.AboutActionListener;
import controls.EditModeActionListener;
import controls.Next1ActionListener;
import controls.ProfileActionListener;

/**
 * Profiles panel. Includes positive, negative and neutral profiles.
 * @author milena
 *
 */
public class ProfilesPanel extends JPanel {
	
	private JComboBox pProfile1;
	private JComboBox pProfile2;
	private JComboBox pProfile3;
	private JComboBox pProfile4;
	private JComboBox nProfile1;
	private JComboBox nProfile2;
	private JComboBox nProfile3;
	private JComboBox nProfile4;
	private JComboBox ngProfile1;
	private JComboBox ngProfile2;
	private JComboBox ngProfile3;
	private JComboBox ngProfile4;
	private JComboBox nbProfile1;
	private JComboBox nbProfile2;
	private JComboBox nbProfile3;
	private JComboBox nbProfile4;
	
	private List<JComboBox> allProfilesList;

	/**
	 * Constructor
	 *
	 */
	public ProfilesPanel(FirstWindow firstWindow)	{
		super();
		this.setLayout(new GridLayout(5, 1));
		ProfileActionListener profAc = new ProfileActionListener(this);
		
		String profileType = "Positif";
		JPanel pPanel = new JPanel();
		pPanel.setBorder(BorderFactory.createTitledBorder("Profils positifs"));
		pPanel.setLayout(new GridLayout(1, 4, 5, 5));
		pProfile1 = new JComboBox();
		initProfilesFromConfig(pProfile1, profileType, profAc);
		pPanel.add(pProfile1);
		pProfile2 = new JComboBox();
		initProfilesFromConfig(pProfile2, profileType, profAc);
		pPanel.add(pProfile2);
		pProfile3 = new JComboBox();
		initProfilesFromConfig(pProfile3, profileType, profAc);
		pPanel.add(pProfile3);
		pProfile4 = new JComboBox();
		initProfilesFromConfig(pProfile4, profileType, profAc);
		pPanel.add(pProfile4);
		this.add(pPanel);
		
		profileType = "Négatif";
		JPanel nPanel = new JPanel();
		nPanel.setBorder(BorderFactory.createTitledBorder("Profils négatifs"));
		nPanel.setLayout(new GridLayout(1, 4, 5, 5));
		nProfile1 = new JComboBox();
		initProfilesFromConfig(nProfile1, profileType, profAc);
		nPanel.add(nProfile1);
		nProfile2 = new JComboBox();
		initProfilesFromConfig(nProfile2, profileType, profAc);
		nPanel.add(nProfile2);
		nProfile3 = new JComboBox();
		initProfilesFromConfig(nProfile3, profileType, profAc);
		nPanel.add(nProfile3);
		nProfile4 = new JComboBox();
		initProfilesFromConfig(nProfile4, profileType, profAc);
		nPanel.add(nProfile4);
		this.add(nPanel);
		
		profileType = "Neutre avantageux";
		JPanel ngPanel = new JPanel();
		ngPanel.setBorder(BorderFactory.createTitledBorder("Profils neutres avantageux"));
		ngPanel.setLayout(new GridLayout(1, 4, 5, 5));
		ngProfile1 = new JComboBox();
		initProfilesFromConfig(ngProfile1, profileType, profAc);
		ngPanel.add(ngProfile1);
		ngProfile2 = new JComboBox();
		initProfilesFromConfig(ngProfile2, profileType, profAc);
		ngPanel.add(ngProfile2);
		ngProfile3 = new JComboBox();
		initProfilesFromConfig(ngProfile3, profileType, profAc);
		ngPanel.add(ngProfile3);
		ngProfile4 = new JComboBox();
		initProfilesFromConfig(ngProfile4, profileType, profAc);
		ngPanel.add(ngProfile4);
		this.add(ngPanel);
		
		profileType = "Neutre désavantageux";
		JPanel nbPanel = new JPanel();
		nbPanel.setBorder(BorderFactory.createTitledBorder("Profils neutres désavantageux"));
		nbPanel.setLayout(new GridLayout(1, 4, 5, 5));
		nbProfile1 = new JComboBox();
		initProfilesFromConfig(nbProfile1, profileType, profAc);
		nbPanel.add(nbProfile1);
		nbProfile2 = new JComboBox();
		initProfilesFromConfig(nbProfile2, profileType, profAc);
		nbPanel.add(nbProfile2);
		nbProfile3 = new JComboBox();
		initProfilesFromConfig(nbProfile3, profileType, profAc);
		nbPanel.add(nbProfile3);
		nbProfile4 = new JComboBox();
		initProfilesFromConfig(nbProfile4, profileType, profAc);
		nbPanel.add(nbProfile4);
		this.add(nbPanel);
		
		makeProfilesList();
		
		//panel to go to next screens
		//(should belong to the window itself - placed here for layout reasons)
		JPanel nextPanel = new JPanel();
		nextPanel.setLayout(new BorderLayout());
		JButton aboutButton = new JButton("A propos ...");
		aboutButton.addActionListener(new AboutActionListener());
		nextPanel.add(aboutButton, BorderLayout.WEST);
		JPanel nextPanel2 = new JPanel();
		nextPanel2.setLayout(new BorderLayout());
		JButton editButton = new JButton("Mode édition");
		editButton.addActionListener(new EditModeActionListener(firstWindow));
		nextPanel2.add(editButton, BorderLayout.WEST);
		JButton nextButton = new JButton("Suivant");
		nextButton.addActionListener(new Next1ActionListener(firstWindow));
		nextPanel2.add(nextButton, BorderLayout.EAST);
		nextPanel.add(nextPanel2, BorderLayout.EAST);
		this.add(nextPanel);
	}
	
	/**
	 * Fills a combo box with the selected profiles list
	 * @param cb the combo box to fill
	 * @param profileType the profiles type filter
	 * @param profAc the action listener to add
	 */
	private void initProfilesFromConfig(JComboBox cb, String profileType, ProfileActionListener profAc)	{
		cb.addItem("");
		for(Profile profile : LyceenneMakerJ.getConfig().getProfiles())	{
			if(profileType.equals(profile.getType()))	{
				cb.addItem(profile.getName());
			}
		}
		cb.setSelectedItem("");
		cb.addActionListener(profAc);
	}
	
	private void makeProfilesList()	{
		allProfilesList = new ArrayList<JComboBox>();
		allProfilesList.add(pProfile1);
		allProfilesList.add(pProfile2);
		allProfilesList.add(pProfile3);
		allProfilesList.add(pProfile4);
		allProfilesList.add(nProfile1);
		allProfilesList.add(nProfile2);
		allProfilesList.add(nProfile3);
		allProfilesList.add(nProfile4);
		allProfilesList.add(ngProfile1);
		allProfilesList.add(ngProfile2);
		allProfilesList.add(ngProfile3);
		allProfilesList.add(ngProfile4);
		allProfilesList.add(nbProfile1);
		allProfilesList.add(nbProfile2);
		allProfilesList.add(nbProfile3);
		allProfilesList.add(nbProfile4);
	}

	public JComboBox getNbProfile1() {
		return nbProfile1;
	}

	public JComboBox getNbProfile2() {
		return nbProfile2;
	}

	public JComboBox getNbProfile3() {
		return nbProfile3;
	}

	public JComboBox getNbProfile4() {
		return nbProfile4;
	}

	public JComboBox getNgProfile1() {
		return ngProfile1;
	}

	public JComboBox getNgProfile2() {
		return ngProfile2;
	}

	public JComboBox getNgProfile3() {
		return ngProfile3;
	}

	public JComboBox getNgProfile4() {
		return ngProfile4;
	}

	public JComboBox getNProfile1() {
		return nProfile1;
	}

	public JComboBox getNProfile2() {
		return nProfile2;
	}

	public JComboBox getNProfile3() {
		return nProfile3;
	}

	public JComboBox getNProfile4() {
		return nProfile4;
	}

	public JComboBox getPProfile1() {
		return pProfile1;
	}

	public JComboBox getPProfile2() {
		return pProfile2;
	}

	public JComboBox getPProfile3() {
		return pProfile3;
	}

	public JComboBox getPProfile4() {
		return pProfile4;
	}

	public List<JComboBox> getAllProfilesList() {
		return allProfilesList;
	}
	
}
