/**
 * Lyceenne Maker J, created by Claire "Milena" Billaud
 * 16 mai 09
 * Copyright (c) 2009, Claire "Milena" Billaud
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Claire Billaud, Milena, nor the
 *       names of other contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package views;

import java.awt.GridLayout;
import java.util.HashMap;
import java.util.Map;

import javax.swing.BorderFactory;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;

import models.Subject;
import program.LyceenneMakerJ;
import controls.SubjectBonusActionListener;
import controls.SubjectNameActionListener;

/**
 * Displays subjects list.
 * @author milena
 *
 */
public class SubjectsListPanel extends JPanel {
	
	private Map<JComboBox, JComboBox> subjects;
	private Map<JComboBox, JLabel> subjectTotals;
	private JLabel totalSubjectsPoints;

	/**
	 * Constructor
	 */
	public SubjectsListPanel() {
		super();
		this.setLayout(new GridLayout(LyceenneMakerJ.getTotalSubjects() + 2, 4, 5, 5));
		this.setBorder(BorderFactory.createTitledBorder("Matières scolaires"));
		subjects = new HashMap<JComboBox, JComboBox>();
		subjectTotals = new HashMap<JComboBox, JLabel>();
		this.add(new JLabel("Nom"));
		this.add(new JLabel("INT"));
		this.add(new JLabel("Bonus"));
		this.add(new JLabel("Score total"));
		initSubjectsList();
		this.add(new JLabel("Points à répartir :"));
		totalSubjectsPoints = new JLabel(Integer.toString(LyceenneMakerJ.getTotalSubjectPoints()));
		this.add(totalSubjectsPoints);
		
	}
	
	/**
	 * Clears and resets panel.
	 * Must be called when numberSubjects changes.
	 *
	 */
	public void clearAllAndReset()	{
		this.removeAll();
		this.setLayout(new GridLayout(LyceenneMakerJ.getTotalSubjects() + 2, 4, 5, 5));
		this.add(new JLabel("Nom"));
		this.add(new JLabel("INT"));
		this.add(new JLabel("Bonus"));
		this.add(new JLabel("Score total"));
		initSubjectsList();
		this.add(new JLabel("Points a répartir :"));
		totalSubjectsPoints.setText(Integer.toString(LyceenneMakerJ.getTotalSubjectPoints()));
		this.add(totalSubjectsPoints);
		this.validate();
		this.repaint();
	}
	
	/**
	 * Initiates an empty subjects list.
	 *
	 */
	public void initSubjectsList()	{
		subjects.clear();
		subjectTotals.clear();
		for (int i = 0; i < LyceenneMakerJ.getTotalSubjects(); i++) {
			JComboBox cbName = new JComboBox();
			cbName.setEditable(false);
			cbName.addItem("");
			for(Subject subject : LyceenneMakerJ.getConfig().getSubjects())	{
				cbName.addItem(subject.getName());
			}
			cbName.setSelectedItem("");
			cbName.addActionListener(new SubjectNameActionListener(this));
			JComboBox cbBonus = new JComboBox();
			cbBonus.setEditable(false);
			for (int j = 0; j <= 20; j++) {
				cbBonus.addItem(Integer.toString(j));
			}
			cbBonus.setSelectedItem("0");
			cbBonus.addActionListener(new SubjectBonusActionListener(this));
			JLabel total = new JLabel(Integer.toString(LyceenneMakerJ.getCurrentCharacter().getCharacteristics().get("INT")));
			//create maps
			subjects.put(cbName, cbBonus);
			subjectTotals.put(cbName, total);
			//display
			this.add(cbName);
			this.add(new JLabel(Integer.toString(LyceenneMakerJ.getCurrentCharacter().getCharacteristics().get("INT"))));
			this.add(cbBonus);
			this.add(total);
		}
	}

	public Map<JComboBox, JComboBox> getSubjects() {
		return subjects;
	}

	public Map<JComboBox, JLabel> getSubjectTotals() {
		return subjectTotals;
	}

	public JLabel getTotalSubjectsPoints() {
		return totalSubjectsPoints;
	}

}
